#!/bin/bash
set -e

# Проект должен быть указан родительским скриптом
if [ ! -n "$PROJECT" ]; then
    echo "❌ Проект не указан!"
    exit 1
fi

PMA_ENV_FILE="${STACKS_DIR}/pma/.env"

# Проверяем, существует ли файл .env
if [ ! -f "$PMA_ENV_FILE" ]; then
    echo "❌ Файл $PMA_ENV_FILE не найден!"
    exit 1
fi

# Временный файл для изменений
TMP_FILE=$(mktemp)

# Обрабатываем каждую строку
while IFS= read -r line; do
    case "$line" in
        HOSTS=*)
            current_hosts=${line#HOSTS=}
            if [[ ! "$current_hosts" =~ "$PROJECT-mariadb-1" ]]; then
                echo "HOSTS=$current_hosts,$PROJECT-mariadb-1" >> "$TMP_FILE"
            else
                echo "$line" >> "$TMP_FILE"
            fi
            ;;
        VERBOSES=*)
            current_verboses=${line#VERBOSES=}
            if [[ ! "$current_verboses" =~ "$PROJECT" ]]; then
                echo "VERBOSES=$current_verboses,$PROJECT" >> "$TMP_FILE"
            else
                echo "$line" >> "$TMP_FILE"
            fi
            ;;
        *)
            echo "$line" >> "$TMP_FILE"
            ;;
    esac
done < "$PMA_ENV_FILE"

# Перемещаем временный файл на место оригинального
mv "$TMP_FILE" "$PMA_ENV_FILE"

echo "✅ Файл $PMA_ENV_FILE обновлён:"
cat "$PMA_ENV_FILE"